#!/usr/bin/env python
"""Django's command-line utility for administrative tasks."""
import logging
import os
import sys

from django.db.migrations import writer

if len(sys.argv) > 1 and sys.argv[1] == 'test':
    logging.disable(logging.WARNING)


writer.MIGRATION_HEADER_TEMPLATE = """\
# Generated by Django %(version)s on %(timestamp)s
# flake8: noqa

"""

def main():
    """Run administrative tasks."""
    cmd = len(sys.argv) > 1 and sys.argv[1]
    os.environ.setdefault(
        "DJANGO_SETTINGS_MODULE",
        cmd == 'test' and "tests.settings.dev" or "pfx.settings.dev")
    try:
        from django.core.management import execute_from_command_line
    except ImportError as exc:
        raise ImportError(
            "Couldn't import Django. Are you sure it's installed and "
            "available on your PYTHONPATH environment variable? Did you "
            "forget to activate a virtual environment?"
        ) from exc
    execute_from_command_line(sys.argv)


if __name__ == '__main__':
    main()



from django.contrib.auth.models import AbstractUser

from .abstract_pfx_base_user import AbstractPFXBaseUser


class PFXUser(AbstractUser, AbstractPFXBaseUser):
    """The Django User with PFX mixin.
    """

    class Meta(AbstractUser.Meta):
        swappable = "AUTH_USER_MODEL"



from django.contrib.auth.models import AbstractBaseUser


class AbstractPFXBaseUser(AbstractBaseUser):
    """The base abstract user for PFX."""

    class Meta:
        abstract = True

    def get_user_jwt_signature_key(self):
        """
        Return a user secret to sign JWT token.

        If not empty, the JWT token validity depends on all values
        user to build the return string. So, each time the returned value
        changes, the previously issued tokens will no longer be valid.
        """
        return self.password
